@@ -342,7 +342,7 @@ def get_parser():
                         help="where is the model folder (with the info.yml)?",
                         metavar="FOLDER",
                         type=lambda x: utils.is_valid_folder(parser, x),
-                        default=utils.default_model(__file__))
+                        default=utils.default_model())
     parser.add_argument("-s", "--set",
                         dest="aset",
                         choices=['test', 'train', 'valid'],
